@@ -4,12 +4,13 @@
 text_name_tools
 ===============
 """
-
+from typing import Union
 import re
 import unidecode
 import random
 from string import punctuation
 import gender_guesser.detector as gender
+from nameparser import HumanName
 
 d = gender.Detector(case_sensitive=False)
 
@@ -81,26 +82,10 @@ def capitalize_name(
        - Maria de Angelis
 
     """
-
-    words = text.split()  # splits only at spaces
-
-    new_words = []
-
-    for word in words:
-        if '-' in word:
-            word = '-'.join([w.title() for w in word.split('-')])
-        elif word.lower() in NAME_PREFIXES:
-            pass
-        else:
-            word = word[0].upper() + word[1:].lower()
-
-        for mac in ('mac', 'mc'):
-            if word.lower().startswith(mac):
-                word = mac.capitalize() + word[len(mac):].capitalize()
-
-        new_words.append(word)
-
-    return ' '.join(new_words)
+    return normalize_name(
+        name=text,
+        returning='str'
+    )
 
 
 def could_be_a_name(
@@ -120,39 +105,60 @@ def could_be_a_name(
     - last character in any word is not uppercase
     - gender can be determined for prename
 
-
     :param default: the default boolean value returned if no check was successfull
                     (neither positively nor negatively)
     """
-    if not name.isalpha():
+    if not name.replace(
+        ' ', ''
+    ).replace(
+        '-', ''
+    ).isalpha():
         return False
 
     # 2 consecutive uppercase chars
-    if re.search('[A-Z]{2}', text):
+    if re.search('[A-Z]{2}', name):
         return False
 
-    text = name.translate(name.maketrans('', '', punctuation))
-    name_elements = text.split()
+    prename = surname = ''
 
-    for el in name_elements:
-        if el[-1].isupper():
+    if ' ' not in name:  # only a single word
+        gender = get_gender(name)
+        if gender in ('male', 'female'):
+            prename = name
+    else:
+        human_name = normalize_name(
+            name=name,
+            returning='HumanName'
+        )
+
+        prename = human_name.first
+        surname = human_name.last
+
+    if not prename and not surname:
+        return False
+
+    for n in (prename, surname):
+        # last char is capital
+        if n[-1].isupper():
             return False
 
-    if len(name_elements) > 1:
-        pre_name = name_elements[0]
-
-    if len(name_elements) > 1 or prename:  # this is only for the prename
-        if get_gender(prename=pre_name) != 'unknown':
-            return True
-
-        sum_upper = sum(c for c in pre_name if c.isupper())
-        if sum_upper != len(pre_name) and sum_upper > 1:
+        # more than 2 capitals
+        if sum(1 for c in n if c.isupper()) > 2:
             return False
 
+    if get_gender(prename=prename) != 'unknown':
+        return True
+
+    sum_upper = sum(1 for c in prename if c.isupper())
+    if sum_upper != len(prename) and sum_upper > 1:
+        return False
+
     return default
 
 
-def get_gender(prename: str) -> str:
+def get_gender(
+    prename: str
+) -> str:
     """ returns: male, female or unknown """
     return d.get_gender(prename)
 
@@ -299,6 +305,30 @@ def map_special_chars(
     return text
 
 
+def normalize_name(
+    name,
+    returning: str = 'str'
+) -> Union[str, dict, HumanName]:
+    """ normalize name
+
+    This function uses the nameparser package
+
+    :param returning:
+        - str: return the name as a string
+        - dict: return a dictionary with the name elements
+        - other: return the HumanName object from nameparser
+    """
+    parsed_name = HumanName(name)
+    parsed_name.capitalize()
+
+    if 'str' in returning:
+        return str(parsed_name)
+    elif 'dict' in returning:
+        return parsed_name.as_dict()
+    else:  # return the HumanName object
+        return parsed_name
+
+
 def sort_word_list(
     word_list: list
 ) -> list:
