@@ -38,6 +38,7 @@ dates_for_checking = {
         'datetime': datetime.datetime(2020, 4, 2),
         'date': datetime.date(2020, 4, 2),
         'DateTime': DateTime.DateTime(2020, 4, 2),
+        'Date': DateTime.DateTime(2020, 4, 2, 12),
         'week': 14,
         'dow_number': 4,
         'monday': datetime.datetime(2020, 3, 30),
@@ -50,6 +51,7 @@ dates_for_checking = {
         'datetime': datetime.datetime(1980, 5, 21),
         'date': datetime.date(1980, 5, 21),
         'DateTime': DateTime.DateTime(1980, 5, 21),
+        'Date': DateTime.DateTime(1980, 5, 21, 12),
         'week': 21,
         'dow_number': 3,
         'monday': datetime.datetime(1980, 5, 19),
@@ -62,6 +64,7 @@ dates_for_checking = {
         'datetime': datetime.datetime(2001, 5, 5),
         'date': datetime.date(2001, 5, 5),
         'DateTime': DateTime.DateTime(2001, 5, 5),
+        'Date': DateTime.DateTime(2001, 5, 5, 12),
         'week': 18,
         'dow_number': 6,
         'monday': datetime.datetime(2001, 4, 30),
@@ -74,6 +77,7 @@ dates_for_checking = {
         'datetime': datetime.datetime(2000, 5, 6),
         'date': datetime.date(2000, 5, 6),
         'DateTime': DateTime.DateTime(2000, 5, 6),
+        'Date': DateTime.DateTime(2000, 5, 6, 12),
         'week': 18,
         'dow_number': 6,
         'monday': datetime.datetime(2000, 5, 1),
@@ -86,6 +90,7 @@ dates_for_checking = {
         'datetime': datetime.datetime(1970, 3, 4),
         'date': datetime.date(1970, 3, 4),
         'DateTime': DateTime.DateTime(1970, 3, 4),
+        'Date': DateTime.DateTime(1970, 3, 4, 12),
         'week': 10,
         'dow_number': 3,
         'monday': datetime.datetime(1970, 3, 2),
@@ -98,6 +103,7 @@ dates_for_checking = {
         'datetime': datetime.datetime(2022, 5, 31),
         'date': datetime.date(2022, 5, 31),
         'DateTime': DateTime.DateTime(2022, 5, 31),
+        'Date': DateTime.DateTime(2022, 5, 31, 12),
         'week': 22,
         'dow_number': 2,
         'monday': datetime.datetime(2022, 5, 30),
@@ -110,6 +116,7 @@ dates_for_checking = {
         'datetime': None,
         'date': None,
         'DateTime': None,
+        'Date': None,
         'week': None,
         'dow_number': None,
         'monday': None,
@@ -122,6 +129,7 @@ dates_for_checking = {
         'datetime': None,
         'date': None,
         'DateTime': None,
+        'Date': None,
         'dow_number': None,
         'monday': None,
         'sunday': None,
@@ -153,7 +161,12 @@ class Test_date_time(unittest.TestCase):
             except AssertionError as e:
                 print(f'- ASS error on {d}: {e}')
 
-    def check_convert_from_to(self, func, convert_from, convert_to):
+    def check_convert_from_to(
+        self,
+        func,
+        convert_from,
+        convert_to
+    ):
         for k, v in dates_for_checking.items():
             fmt = v.get('convert_fmt')
 
@@ -187,29 +200,57 @@ class Test_date_time(unittest.TestCase):
                     raise AssertionError(e)
 
     def test_str_to_dt(self):
-        self.check_convert_from_to(func=str_to_dt, convert_from='string', convert_to='datetime')
+        self.check_convert_from_to(
+            func=str_to_dt,
+            convert_from='string',
+            convert_to='datetime'
+        )
 
     def test_str_to_date(self):
-        self.check_convert_from_to(func=str_to_date, convert_from='string', convert_to='date')
+        self.check_convert_from_to(
+            func=str_to_date,
+            convert_from='string',
+            convert_to='date'
+        )
 
     def test_str_to_DT(self):
-        self.check_convert_from_to(func=str_to_DT, convert_from='string', convert_to='DateTime')
+        self.check_convert_from_to(
+            func=str_to_DT,
+            convert_from='string',
+            convert_to='DateTime'
+        )
 
     def test_DT_to_dt(self):
-        self.check_convert_from_to(func=DT_to_dt, convert_from='DateTime', convert_to='datetime')
+        self.check_convert_from_to(
+            func=DT_to_dt,
+            convert_from='DateTime',
+            convert_to='datetime'
+        )
 
     def test_DT_to_date(self):
-        self.check_convert_from_to(func=DT_to_date, convert_from='DateTime', convert_to='date')
+        self.check_convert_from_to(
+            func=DT_to_date,
+            convert_from='DateTime',
+            convert_to='date'
+        )
 
     def test_date_to_dt(self):
-        self.check_convert_from_to(func=date_to_dt, convert_from='date', convert_to='datetime')
+        self.check_convert_from_to(
+            func=date_to_dt,
+            convert_from='date',
+            convert_to='datetime'
+        )
 
     def test_date_to_DT(self):
-        self.check_convert_from_to(func=date_to_DT, convert_from='date', convert_to='DateTime')
+        self.check_convert_from_to(
+            func=date_to_DT,
+            convert_from='date',
+            convert_to='DateTime'
+        )
 
     def test_convert_datetime(self):
         convert_tos = ('string', 'datetime', 'date', 'DateTime')
-        converts = set()
+        converts = []
 
         for s, v in dates_for_checking.items():
             for k in convert_tos:
@@ -221,7 +262,7 @@ class Test_date_time(unittest.TestCase):
                 if not t:
                     continue
 
-                converts.add((s, t))
+                converts.append((s, t))
 
         for date_string, conv_from in converts:
             dates_for_checking_val = dates_for_checking.get(date_string)
@@ -233,17 +274,27 @@ class Test_date_time(unittest.TestCase):
                 if check_obj is not None:
 
                     try:
-                        res_obj = convert_datetime(date=conv_from, convert_to=conv_to, fmt=convert_fmt)
+                        res_obj = convert_datetime(
+                            date=conv_from,
+                            convert_to=conv_to,
+                            fmt=convert_fmt
+                        )
                     except ValueError as e:
                         if 'is not a valid date or datetime string.' in str(e):
-                            # Exception in get_dateformat, validity is tested in the appropriate test function
+                            # Exception in get_dateformat,
+                            # validity is tested in the appropriate test function
                             continue
                         elif 'does not match format' in str(e):
                             continue
                         else:
                             raise ValueError(e)
 
-                    self.assertEqual(res_obj, check_obj)
+                    try:
+                        self.assertEqual(res_obj, check_obj)
+                    except AssertionError as e:
+                        raise AssertionError(
+                            f'convert from {conv_from} to: {conv_to}\n{e}'
+                        )
 
     def test_get_calendar_week(self):
         for s, v in dates_for_checking.items():
@@ -252,7 +303,12 @@ class Test_date_time(unittest.TestCase):
             if not correct_week:
                 continue
 
-            for some_date in (s, v.get('date'), v.get('datetime'), v.get('DateTime')):
+            for some_date in (
+                s,
+                v.get('date'),
+                v.get('datetime'),
+                v.get('DateTime')
+            ):
                 week = get_calendar_week(some_date)
 
                 self.assertEqual(week, correct_week)
@@ -264,7 +320,12 @@ class Test_date_time(unittest.TestCase):
             if not correct_dow_number:
                 continue
 
-            for some_date in (s, v.get('date'), v.get('datetime'), v.get('DateTime')):
+            for some_date in (
+                s,
+                v.get('date'),
+                v.get('datetime'),
+                v.get('DateTime')
+            ):
                 dow_number = get_dow_number(some_date)
 
                 self.assertEqual(dow_number, correct_dow_number)
@@ -276,7 +337,12 @@ class Test_date_time(unittest.TestCase):
             if not correct_isocalendar:
                 continue
 
-            for some_date in (s, v.get('date'), v.get('datetime'), v.get('DateTime')):
+            for some_date in (
+                s,
+                v.get('date'),
+                v.get('datetime'),
+                v.get('DateTime')
+            ):
                 iso_calendar = get_isocalendar(some_date)
 
                 self.assertEqual(iso_calendar, correct_isocalendar)
@@ -292,7 +358,11 @@ class Test_date_time(unittest.TestCase):
             week = v.get('week')
             dow = v.get('dow_number')
 
-            day = day_from_week(year=year, week=week, weekday=dow)
+            day = day_from_week(
+                year=year,
+                week=week,
+                weekday=dow
+            )
 
             self.assertEqual(day, correct_day)
 
@@ -306,9 +376,15 @@ class Test_date_time(unittest.TestCase):
             year = correct_monday.year
             week = v.get('week')
 
-            monday = monday_from_week(year=year, week=week)
+            monday = monday_from_week(
+                year=year,
+                week=week
+            )
 
-            self.assertEqual(monday, correct_monday)
+            self.assertEqual(
+                monday,
+                correct_monday
+            )
 
     def test_last_week_of_year(self):
         for s, v in dates_for_checking.items():
@@ -319,7 +395,10 @@ class Test_date_time(unittest.TestCase):
 
             last_week = last_week_of_year(v.get('datetime').year)
 
-            self.assertEqual(last_week, correct_last_week)
+            self.assertEqual(
+                last_week,
+                correct_last_week
+            )
 
     def test_daterange_from_week(self):
         for s, v in dates_for_checking.items():
@@ -332,9 +411,15 @@ class Test_date_time(unittest.TestCase):
             correct_sunday = v.get('sunday')
             year = v.get('datetime').year
 
-            daterange = daterange_from_week(year=year, week=week)
+            daterange = daterange_from_week(
+                year=year,
+                week=week
+            )
 
-            self.assertEqual(daterange, (correct_monday, correct_sunday))
+            self.assertEqual(
+                daterange,
+                (correct_monday, correct_sunday)
+            )
 
     def test_dates_from_week(self):
         for s, v in dates_for_checking.items():
@@ -352,12 +437,18 @@ class Test_date_time(unittest.TestCase):
             for i in range(1, 7):
                 correct_dates.append(monday + datetime.timedelta(days=i))
 
-            dates = dates_from_week(year=year, week=week)
+            dates = dates_from_week(
+                year=year,
+                week=week
+            )
 
-            self.assertEqual(dates, correct_dates)
+            self.assertEqual(
+                dates,
+                correct_dates
+            )
 
 
 if __name__ == '__main__':
     unittest.main()
 
-    print('finished date_time tests.')
+    # print('finished date_time tests.')
